#include <qapplication.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qfont.h>
#include <qlayout.h>
#include <qstring.h>

#include "painter.h"
#include "canvas.h"


Painter::Painter( QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    setMinimumSize( 500, 355 );

    QPushButton *quit = new QPushButton( "Quit", this, "quit" );
    quit->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );
    canvas = new Canvas( this, "canvas" );
	connect( canvas, SIGNAL(changePos()), SLOT(newPosition( )) );
	connect( canvas, SIGNAL(changeSize()), SLOT(newSize( )) );

    stop = new QPushButton( "Stop", this, "stop" );
    stop->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( stop, SIGNAL(clicked()), canvas, SLOT(stopMove()) );

    start = new QPushButton( "Start", this, "start" );
    start->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( start, SIGNAL(clicked()), canvas, SLOT(startMove()) );

    QGridLayout *grid = new QGridLayout( this, 1, 2, 5 ); //2x2, 5 pixel border
    grid->addWidget( canvas, 0, 1 );
    grid->setColStretch( 1, 10 );

    messpos = new QLabel( this, "messagepos"  );
    messpos->setMaximumHeight( 20 );
    messpos->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
    messpos->setBackgroundColor( messpos->colorGroup().base() );
    messpos->setAlignment( AlignCenter );

    messize = new QLabel( this, "message_size"  );
    messize->setMaximumHeight( 20 );
    messize->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
    messize->setBackgroundColor( messpos->colorGroup().base() );
    messize->setAlignment( AlignCenter );

	QVBoxLayout *leftBox = new QVBoxLayout;
	grid->addLayout( leftBox, 0, 0 );
	leftBox->addWidget( quit );
	leftBox->addWidget( stop );
	leftBox->addWidget( start );
	leftBox->addWidget( messpos );
	leftBox->addWidget( messize );
}

void Painter::newPosition( )
{
	int mx, my;

	canvas->getPosition( &mx, &my );

    QString s;
	messpos->setText( s.sprintf("%d,%d", mx, my ) );
}

void Painter::newSize( )
{
	int mx, my;

	canvas->getSize( &mx, &my );

    QString s;
	messize->setText( s.sprintf("%d,%d", mx, my ) );
}
